%% Extract a subset of common-offset data from the first-arrival travel-time
%% matrix 'ttime'.
%%
%%	For each source, a line is drawn in the direction of azimuth 'azim',
%%	and receivers close to this line are selected. From these receivers,
%%	a travel-time surcve is constructed and interpolated at the given offset.
%%	The resulting travel time is attributed to the position of the source.
%%
%% Parameters:
%%	azim - azimuth in degrees for which to do the common-offset extraction
%%	maxdist - maximum distance from the line (meters) for receiver included
%%		in the outputs (as in gather_common_azimuth())
%%
%% Returns:
%%	tt - array of travel times 
%%	src - array of source numbers for which tt is output

function [ tt, src ] = map_common_offset(azim,offset,maxdist)

	global survey xi yi ttime offsets xgrid ygrid src_station

	% initialize empty outputs

	tt = [];
	src = [];

	% work with each source separately

	for i=1:size(src_station,1)

		# extract travel time along the azimuth

		[ tt1, d1, offs1, rec1 ] = gather_common_azimuth(i,azim,maxdist,true);

		# interpolate the travel time to exact 'offset'

% ot = [ offs1; tt1 ]  % test printout

		if min(offs1) <= offset && offset <= max(offs1)

		  % offs1 is sometimes non-incrreasing near the source
		  % interp1() does not like this; so sorting off1 first

			[ o, ind ] = sort(offs1);

			tt = [ tt, interp1(o,tt1(ind),offset) ];
			src = [src, i ];
		end
	end
end

