%% Calculates the refraction travel time delay at point 'xy'
%% The shape of the refractor should be provided by global variables xgrid, ygrid, and refractor1
%%
%% Parameters:
%%	xy - matrix; each row is an array of two (x,y) coordinates of the point 
%%		at which the delay is calculated
%%	V0 - velocity above the refractor
%%	Vrefr - velocity below the refractor
%% Returns:
%%	delay - delay time at point xy. This should be a column vector with
%%			number of rows equal that in 'xy'

function delay = tt_delay(xy,V0,Vrefr)

global refractor1

	% determine the depths to refractor1 at points xy

	h = griddata(refractor1(:,1), refractor1(:,2), refractor1(:,3), xy(:,1), xy(:,2), 'linear');
  
  %% determine critical angle 
  i_c = asin(V0/Vrefr);
  
	delay = (h*cos(i_c))/V0;	
end

