%% Returns the linear-moveout part of refraction or direct-wave travel time
%%
%% Parameters:
%%	xyS - matrix in which each row contains two (x,y) coordinates of the source
%%	xyR - matrix in which each row containstwo (x,y) coordinates of the receiver
%%		xyS and xyR should have equal numbers of rows (number of points to output)
%%	V0 - moveout velocity 
%%
%% Returns:
%%	t - linear-moveout part of the refraction travel time 
%%		This should be a column vector with
%%		number of rows equal that in 'xyS' and 'xyR'
%%	distance - column of source-receiver distances for each pair (xyS, xyR)
%%	azimuth - column of source-receiver azimuths for each pair (xyS, xyR)
%%	mid_xy - column of midpoints between each pair (xyS, xyR)
%% 		We want to return these midpoints because later, we will try constructing
%%		common-midpoint travel times

function [ t distance azmth mid_xy ] = tt_linear_moveout(xyS,xyR,V)

	distance = sqrt((xyR(:,1)-xyS(:,1)).^2 + (xyR(:,2)-xyS(:,2)).^2);	
	azmth = azimuth(xyS,xyR);	

	mid_xy = (xyR + xyS)*0.5;

	t = distance / V;	
end

